@@ -19,12 +19,27 @@ from zope.interface import implementer
 class PagesView(FolderView):
     """Pages view"""
 
+    b_size = 40
+
     def __call__(self):
+        # get gallery sections and sections with gallery
         galleries_sections = self.context.listFolderContents(
-            contentFilter={"portal_type": "imio.smartweb.SectionGallery"}
+            contentFilter={
+                "portal_type": [
+                    "imio.smartweb.SectionGallery",
+                    "imio.smartweb.SectionContact",
+                ]
+            }
         )
         if len(galleries_sections) > 0:
             add_bundle_on_request(self.request, "spotlightjs")
+        for index, gs in enumerate(galleries_sections):
+            if (
+                gs.portal_type == "imio.smartweb.SectionContact"
+                and gs.gallery_mode != "gallery"
+            ):
+                galleries_sections.pop(index)
+        if len(galleries_sections) > 0:
             add_bundle_on_request(self.request, "flexbin")
         return self.index()
 
@@ -35,7 +50,7 @@ class PagesView(FolderView):
         # Extra filter
         kwargs.update(self.request.get("contentFilter", {}))
         kwargs.setdefault("batch", True)
-        kwargs.setdefault("b_size", 30)
+        kwargs.setdefault("b_size", self.b_size)
         kwargs.setdefault("b_start", self.b_start)
         kwargs.setdefault("orphan", 1)
 
